# frozen_string_literal: true

require 'toml'

# Loads and handles the application configuration.
class Config

  # class constructor
  def initialize(config_path)
    expanded_path = File.expand_path(config_path)
    @config = TOML.load_file(expanded_path)

    # just in case the user wants to use a tilde (~) in the repository path...
    @config['transcoder']['repository'] = File.expand_path(get('transcoder.repository'))
  end

  # returns a configuration value from a dot-seperated string, like 'transcoder.interval'
  def get(path)
    value = @config
    bits = path.split('.')
    bits.each { |bit|
      if value.key?(bit)
        value = value[bit]
      else
        abort("Configuration value #{path} does exist.")
      end
    }

    return value
  end

end
