# frozen_string_literal: true

require 'pathname'

# Handles the actual transcoding.
class Transcoder

  def initialize(config, repository)
    @config = config
    @repository = repository
  end

  def start
    puts 'Starting transcoder...'

    # search for files in ingest
    ingest_files = @repository.search_ingest
    ingest_files.each { |ifile|
      # archive the file
      @repository.archive_file(ifile)
      # perform the transcode
      transcode(ifile)
      # clean up the file from ingest
      @repository.cleanup_file(ifile)
    }
  end

  def transcode(ingest_file)
    # create the ingest and output file paths
    ingest_path = File.join(@config.get('transcoder.repository'), 'ingest', ingest_file)
    out_name = "#{File.basename(ingest_file, File.extname(ingest_file))}.#{@config.get('transcoder.video_format')}"
    output_path = File.join(@config.get('transcoder.repository'), 'output', out_name)

    ffmpeg_cmd = build_ffmpeg_cmd(ingest_path, output_path)

    # execute the FFMPEG command
    puts "Transcoding #{ingest_path} to #{output_path}."
    result = `#{ffmpeg_cmd} 2>&1 >/dev/null`

    abort "Transcoding failed with error:\n#{result}" if result.end_with?("Conversion failed!\n")
  end

  def build_ffmpeg_cmd(ingest_path, output_path)
    # put together the ffmpeg command
    "/usr/bin/ffmpeg -i #{ingest_path} -y" \
      " -f #{@config.get('transcoder.video_format')}" \
      " -c:v #{@config.get('transcoder.video_codec')}" \
      " -s #{@config.get('transcoder.video_resolution')}" \
      " -r #{@config.get('transcoder.video_framerate')}" \
      " -vf 'format=#{@config.get('transcoder.video_color')}'" \
      " -profile:v #{@config.get('transcoder.video_profile')}" \
      " -c:a #{@config.get('transcoder.audio_codec')}" \
      " #{output_path}"
  end

end
